@@ -17,7 +17,7 @@ class PDF::StructTreeRoot
     use PDF::NameTree;
     use PDF::NumberTree;
 
-    has PDF::COS::Name $.Type is entry(:required) where 'StructTreeRoot';
+    has PDF::COS::Name $.Type is entry(:required, :alias<type>) where 'StructTreeRoot';
     has PDF::StructElem @.K is entry( :alias<kids>, :array-or-item );  # The immediate child or children of the structure tree root in the structure hierarchy. The value may be either a dictionary representing a single structure element or an array of such dictionaries.
     has PDF::NameTree[StructElemChild, :coerce(&coerce-struct-kids)] $.IDTree is entry;          # (Required if any structure elements have element identifiers) A name tree that maps element identifiers to the structure elements they denote.
     has PDF::NumberTree[StructElemChild, :coerce(&coerce-struct-kids)] $.ParentTree is entry;    # (Required if any structure element contains content items) A number tree used in finding the structure elements to which content items belong. Each integer key in the number tree shall correspond to a single page of the document or to an individual object (such as an annotation or an XObject) that is a content item in its own right. The integer key shall be the value of the StructParent or StructParents entry in that object. The form of the associated value shall depend on the nature of the object:
